@@ -85,7 +85,11 @@ class ProvisioningArtifactParametersTask(ProvisioningTask):
                 ).get(
                     "ProvisioningArtifactParameters", []
                 )
-                self.write_output(provisioning_artifact_parameters)
+                self.write_output(
+                    provisioning_artifact_parameters
+                    if isinstance(provisioning_artifact_parameters, list)
+                    else [provisioning_artifact_parameters]
+                )
 
 
 class ProvisionProductTask(ProvisioningTask):
@@ -112,7 +116,7 @@ class ProvisionProductTask(ProvisioningTask):
     should_use_product_plans = luigi.BoolParameter(significant=False, default=False)
     requested_priority = luigi.IntParameter(significant=False, default=0)
 
-    execution_mode = luigi.Parameter()
+    execution = luigi.Parameter()
 
     try_count = 1
     all_params = []
@@ -125,6 +129,7 @@ class ProvisionProductTask(ProvisioningTask):
             "portfolio": self.portfolio,
             "product": self.product,
             "version": self.version,
+            "execution": self.execution,
         }
 
     @property
@@ -339,7 +344,7 @@ class ProvisionProductTask(ProvisioningTask):
                                 path_id,
                                 params_to_use,
                                 self.version,
-                                self.execution_mode,
+                                self.execution,
                             )
 
                     else:
@@ -355,10 +360,14 @@ class ProvisionProductTask(ProvisioningTask):
                             params_to_use,
                             self.version,
                             self.should_use_sns,
-                            self.execution_mode,
+                            self.execution,
                         )
 
-                if self.execution_mode == constants.EXECUTION_MODE_HUB:
+                self.info(f"self.execution_mode is {self.execution}")
+                if self.execution == constants.EXECUTION_MODE_HUB:
+                    self.info(
+                        f"Running in execution mode: {self.execution}, checking for SSM outputs"
+                    )
                     with betterboto_client.CrossAccountClientContextManager(
                         "cloudformation",
                         role,
@@ -1040,7 +1049,7 @@ class LaunchInSpokeTask(ProvisioningTask):
 
         tasks_to_run = self.generate_tasks(launch_tasks_def, manifest)
         yield tasks_to_run
-        self.write_output()
+        self.write_output(self.params_for_results_display())
 
 
 class LaunchTask(ProvisioningTask):
@@ -1056,6 +1065,7 @@ class LaunchTask(ProvisioningTask):
     def params_for_results_display(self):
         return {
             "launch_name": self.launch_name,
+            "execution_mode": self.execution_mode,
         }
 
     def requires(self):
@@ -1128,6 +1138,8 @@ class LaunchTask(ProvisioningTask):
         configuration["should_use_sns"] = self.should_use_sns
         configuration["should_use_product_plans"] = self.should_use_product_plans
 
+        configuration["execution"] = launch.get("execution")
+
         launch_tasks_def = manifest.get_task_defs_from_details(
             self.puppet_account_id, False, self.launch_name, configuration, "launches"
         )
@@ -1261,50 +1273,50 @@ class SpokeLocalPortfolioTask(ProvisioningTask):
                 )
                 tasks.append(create_spoke_local_portfolio_task)
 
-        create_spoke_local_portfolio_task_as_dependency_params = {
-            "manifest_file_path": self.manifest_file_path,
-            "account_id": task_def.get("account_id"),
-            "region": task_def.get("region"),
-            "portfolio": portfolio,
-            "organization": task_def.get("organization"),
-        }
-
-        if len(task_def.get("associations", [])) > 0:
-            create_associations_for_portfolio_task = portfoliomanagement_tasks.CreateAssociationsForPortfolioTask(
-                **create_spoke_local_portfolio_task_as_dependency_params,
-                associations=task_def.get("associations"),
-                puppet_account_id=task_def.get("puppet_account_id"),
-                should_use_sns=task_def.get("should_use_sns"),
-            )
-            tasks.append(create_associations_for_portfolio_task)
-
-        launch_constraints = task_def.get("constraints", {}).get("launch", [])
-
-        if product_generation_method == "import":
-            import_into_spoke_local_portfolio_task = portfoliomanagement_tasks.ImportIntoSpokeLocalPortfolioTask(
-                **create_spoke_local_portfolio_task_as_dependency_params,
-                puppet_account_id=task_def.get("puppet_account_id"),
-            )
-            tasks.append(import_into_spoke_local_portfolio_task)
-        else:
-            copy_into_spoke_local_portfolio_task = portfoliomanagement_tasks.CopyIntoSpokeLocalPortfolioTask(
-                **create_spoke_local_portfolio_task_as_dependency_params,
-                puppet_account_id=task_def.get("puppet_account_id"),
-            )
-            tasks.append(copy_into_spoke_local_portfolio_task)
-
-        if len(launch_constraints) > 0:
-            create_launch_role_constraints_for_portfolio_task_params = {
-                "launch_constraints": launch_constraints,
-                "puppet_account_id": task_def.get("puppet_account_id"),
-                "should_use_sns": task_def.get("should_use_sns"),
+            create_spoke_local_portfolio_task_as_dependency_params = {
+                "manifest_file_path": self.manifest_file_path,
+                "account_id": task_def.get("account_id"),
+                "region": task_def.get("region"),
+                "portfolio": portfolio,
+                "organization": task_def.get("organization"),
             }
-            create_launch_role_constraints_for_portfolio = portfoliomanagement_tasks.CreateLaunchRoleConstraintsForPortfolio(
-                **create_spoke_local_portfolio_task_as_dependency_params,
-                **create_launch_role_constraints_for_portfolio_task_params,
-                product_generation_method=product_generation_method,
-            )
-            tasks.append(create_launch_role_constraints_for_portfolio)
+
+            if len(task_def.get("associations", [])) > 0:
+                create_associations_for_portfolio_task = portfoliomanagement_tasks.CreateAssociationsForPortfolioTask(
+                    **create_spoke_local_portfolio_task_as_dependency_params,
+                    associations=task_def.get("associations"),
+                    puppet_account_id=task_def.get("puppet_account_id"),
+                    should_use_sns=task_def.get("should_use_sns"),
+                )
+                tasks.append(create_associations_for_portfolio_task)
+
+            launch_constraints = task_def.get("constraints", {}).get("launch", [])
+
+            if product_generation_method == "import":
+                import_into_spoke_local_portfolio_task = portfoliomanagement_tasks.ImportIntoSpokeLocalPortfolioTask(
+                    **create_spoke_local_portfolio_task_as_dependency_params,
+                    puppet_account_id=task_def.get("puppet_account_id"),
+                )
+                tasks.append(import_into_spoke_local_portfolio_task)
+            else:
+                copy_into_spoke_local_portfolio_task = portfoliomanagement_tasks.CopyIntoSpokeLocalPortfolioTask(
+                    **create_spoke_local_portfolio_task_as_dependency_params,
+                    puppet_account_id=task_def.get("puppet_account_id"),
+                )
+                tasks.append(copy_into_spoke_local_portfolio_task)
+
+            if len(launch_constraints) > 0:
+                create_launch_role_constraints_for_portfolio_task_params = {
+                    "launch_constraints": launch_constraints,
+                    "puppet_account_id": task_def.get("puppet_account_id"),
+                    "should_use_sns": task_def.get("should_use_sns"),
+                }
+                create_launch_role_constraints_for_portfolio = portfoliomanagement_tasks.CreateLaunchRoleConstraintsForPortfolio(
+                    **create_spoke_local_portfolio_task_as_dependency_params,
+                    **create_launch_role_constraints_for_portfolio_task_params,
+                    product_generation_method=product_generation_method,
+                )
+                tasks.append(create_launch_role_constraints_for_portfolio)
         logger.info(f"tasks len are {len(tasks)}")
         logger.info(f"tasks are {tasks}")
         return tasks
